@@ -13,7 +13,8 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from pynetbox.core.response import Record, JsonField
+
+from pynetbox.core.response import JsonField, Record
 from pynetbox.models.ipam import IpAddresses
 
 
